# HTML Components

## What are HTML Components?

HTML components are some simple set of classes that can be used to create a HTML website fast and easily. These components are very easy to use and can be used to create a HTML website in a few lines of code. Try to create a HTML website using these components and you will see how easy it is to create a HTML website using these components. So, let's get started.

## Built-in HTML Components

`Html` : To create the main HTML page layout.

`Head` : To create the head section of a html website.

`Title`: To describe the title of a website in the head section.

`Meta` : To describe all types of meta tags for SEO.

`Body` : To create the body structure of a html website.

`Script`: To load Javascript codes in fronty based website.

`Style`: To write custom CSS fronty.

`Link` : To load CSS codes in fronty based website.

`Anchor` : To create a anchor links in a html website.

`Image` : To load images in a html website.

`Button` : To create a button in a html website.

`Input` : To create a input field in a html website.

`Text` : To create a text in a html website.

`Break` : To create a break line in a html website.

`Form` : To create a form in a html website.

`Div` : To create a div in a html website.

`Span` : To create a span in a html website.

`H1` : To create a h1 in a html website.

`H2` : To create a h2 in a html website.

`H3` : To create a h3 in a html website.

`H4` : To create a h4 in a html website.

`H5` : To create a h5 in a html website.

`H6` : To create a h6 in a html website.

`P` : To create a p in a html website.

`Ul` : To create a ul in a html website.

`Ol` : To create a ol in a html website.

`Li` : To create a li in a html website.

`Table` : To create a table in a html website.

`Tr` : To create a tr in a html website.

`Td` : To create a td in a html website.

`Th` : To create a th in a html website.

`Caption` : To create a caption in a html website.

`Thead` : To create a thead in a html website.

`Tbody` : To create a tbody in a html website.

`Tfoot` : To create a tfoot in a html website.

`Iframe` : To create a iframe in a html website.

`Audio` : To create a audio in a html website.

`Video` : To create a video in a html website.

`Source` : To create a source in a html website.

`Select` : To create a select in a html website.

`Option` : To create a option in a html website.

`Nav` : To create a nav in a html website.

`Header` : To create a header in a html website.

`Footer` : To create a footer in a html website.

`Section` : To create a section in a html website.

`Article` : To create a article in a html website.

`Aside` : To create a aside in a html website.

`Main` : To create a main in a html website.

`Figure` : To create a figure in a html website.

`Figcaption` : To create a figcaption in a html website.

`Dl` : To create a dl in a html website.

`Dt` : To create a dt in a html website.

`Dd` : To create a dd in a html website.

`Time` : To create a time in a html website.

`Mark` : To create a mark in a html website.

`Small` : To create a small in a html website.

`Strong` : To create a strong in a html website.

`Em` : To create a em in a html website.

`Code` : To create a code in a html website.

`Pre` : To create a pre in a html website.

`Blockquote` : To create a blockquote in a html website.

`Empty` : To wrap multiple elements to return a single element.

`Comment` : To create a comment in a html website.

##
